@@ -3,21 +3,17 @@ Model for a Zwave Node's endpoints.
 
 https://zwave-js.github.io/node-zwave-js/#/api/endpoint?id=endpoint-properties
 """
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, TypedDict, cast
 
-from ..const import TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED, NodeStatus
+from ..const import NodeStatus
 from ..event import EventBase
 from ..exceptions import FailedCommand, NotFoundError
 from .command_class import CommandClass, CommandClassInfo, CommandClassInfoDataType
 from .device_class import DeviceClass, DeviceClassDataType
 from .value import ConfigurationValue, Value
 
-if TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED:
-    from typing_extensions import TypedDict
-else:
-    from typing import TypedDict
-
 if TYPE_CHECKING:
     from ..client import Client
     from .node.data_model import NodeDataType
@@ -28,10 +24,11 @@ class EndpointDataType(TypedDict, total=False):
 
     nodeId: int  # required
     index: int  # required
-    deviceClass: DeviceClassDataType  # required
+    deviceClass: DeviceClassDataType
     installerIcon: int
     userIcon: int
-    commandClasses: List[CommandClassInfoDataType]
+    endpointLabel: str
+    commandClasses: list[CommandClassInfoDataType]  # required
 
 
 class Endpoint(EventBase):
@@ -41,13 +38,13 @@ class Endpoint(EventBase):
         self,
         client: "Client",
         data: EndpointDataType,
-        values: Dict[str, Union[ConfigurationValue, Value]],
+        values: dict[str, ConfigurationValue | Value],
     ) -> None:
         """Initialize."""
         super().__init__()
         self.client = client
-        self.data: EndpointDataType = {}
-        self.values: Dict[str, Union[ConfigurationValue, Value]] = {}
+        self.data: EndpointDataType = data
+        self.values: dict[str, ConfigurationValue | Value] = {}
         self.update(data, values)
 
     def __repr__(self) -> str:
@@ -79,29 +76,34 @@ class Endpoint(EventBase):
         return self.data["index"]
 
     @property
-    def device_class(self) -> DeviceClass:
+    def device_class(self) -> DeviceClass | None:
         """Return the device_class."""
+        if "deviceClass" not in self.data:
+            return None
         return DeviceClass(self.data["deviceClass"])
 
     @property
-    def installer_icon(self) -> Optional[int]:
+    def installer_icon(self) -> int | None:
         """Return installer icon property."""
         return self.data.get("installerIcon")
 
     @property
-    def user_icon(self) -> Optional[int]:
+    def user_icon(self) -> int | None:
         """Return user icon property."""
         return self.data.get("userIcon")
 
     @property
-    def command_classes(self) -> List[CommandClassInfo]:
+    def command_classes(self) -> list[CommandClassInfo]:
         """Return all CommandClasses supported on this node."""
         return [CommandClassInfo(cc) for cc in self.data["commandClasses"]]
 
+    @property
+    def endpoint_label(self) -> str | None:
+        """Return endpoint label property."""
+        return self.data.get("endpointLabel")
+
     def update(
-        self,
-        data: EndpointDataType,
-        values: Dict[str, Union[ConfigurationValue, Value]],
+        self, data: EndpointDataType, values: dict[str, ConfigurationValue | Value]
     ) -> None:
         """Update the endpoint data."""
         self.data = data
@@ -119,10 +121,10 @@ class Endpoint(EventBase):
     async def async_send_command(
         self,
         cmd: str,
-        require_schema: Optional[int] = None,
-        wait_for_result: Optional[bool] = None,
+        require_schema: int | None = None,
+        wait_for_result: bool | None = None,
         **cmd_kwargs: Any,
-    ) -> Optional[Dict[str, Any]]:
+    ) -> dict[str, Any] | None:
         """
         Send an endpoint command. For internal use only.
 
@@ -158,7 +160,7 @@ class Endpoint(EventBase):
         command_class: CommandClass,
         method_name: str,
         *args: Any,
-        wait_for_result: bool = None,
+        wait_for_result: bool | None = None,
     ) -> Any:
         """Call endpoint.invoke_cc_api command."""
         if not any(cc.id == command_class.value for cc in self.command_classes):
